# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/enterprise_participant_replication_service.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'com/digitalasset/canton/admin/participant/v30/enterprise_participant_replication_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n^com/digitalasset/canton/admin/participant/v30/enterprise_participant_replication_service.proto\x12-com.digitalasset.canton.admin.participant.v30\"\x13\n\x11SetPassiveRequest\"\x14\n\x12SetPassiveResponse2\xbd\x01\n\'EnterpriseParticipantReplicationService\x12\x91\x01\n\nSetPassive\x12@.com.digitalasset.canton.admin.participant.v30.SetPassiveRequest\x1a\x41.com.digitalasset.canton.admin.participant.v30.SetPassiveResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.enterprise_participant_replication_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_SETPASSIVEREQUEST']._serialized_start=145
  _globals['_SETPASSIVEREQUEST']._serialized_end=164
  _globals['_SETPASSIVERESPONSE']._serialized_start=166
  _globals['_SETPASSIVERESPONSE']._serialized_end=186
  _globals['_ENTERPRISEPARTICIPANTREPLICATIONSERVICE']._serialized_start=189
  _globals['_ENTERPRISEPARTICIPANTREPLICATIONSERVICE']._serialized_end=378
# @@protoc_insertion_point(module_scope)
