# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/participant_repair_service.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'com/digitalasset/canton/admin/participant/v30/participant_repair_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import synchronizer_connectivity_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNcom/digitalasset/canton/admin/participant/v30/participant_repair_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1aMcom/digitalasset/canton/admin/participant/v30/synchronizer_connectivity.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9d\x01\n\x15PurgeContractsRequest\x12-\n\x12synchronizer_alias\x18\x01 \x01(\tR\x11synchronizerAlias\x12!\n\x0c\x63ontract_ids\x18\x02 \x03(\tR\x0b\x63ontractIds\x12\x32\n\x15ignore_already_purged\x18\x03 \x01(\x08R\x13ignoreAlreadyPurged\"\x18\n\x16PurgeContractsResponse\"\xaf\x03\n\x18\x43hangeAssignationRequest\x12:\n\x19source_synchronizer_alias\x18\x01 \x01(\tR\x17sourceSynchronizerAlias\x12:\n\x19target_synchronizer_alias\x18\x02 \x01(\tR\x17targetSynchronizerAlias\x12#\n\rskip_inactive\x18\x03 \x01(\x08R\x0cskipInactive\x12n\n\tcontracts\x18\x04 \x03(\x0b\x32P.com.digitalasset.canton.admin.participant.v30.ChangeAssignationRequest.ContractR\tcontracts\x1a\x85\x01\n\x08\x43ontract\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12G\n\x1dreassignment_counter_override\x18\x02 \x01(\x03H\x00R\x1breassignmentCounterOverride\x88\x01\x01\x42 \n\x1e_reassignment_counter_override\"\x1b\n\x19\x43hangeAssignationResponse\"\x8f\x02\n\x1aMigrateSynchronizerRequest\x12:\n\x19source_synchronizer_alias\x18\x01 \x01(\tR\x17sourceSynchronizerAlias\x12\x9e\x01\n%target_synchronizer_connection_config\x18\x02 \x01(\x0b\x32K.com.digitalasset.canton.admin.participant.v30.SynchronizerConnectionConfigR\"targetSynchronizerConnectionConfig\x12\x14\n\x05\x66orce\x18\x03 \x01(\x08R\x05\x66orce\"\x1d\n\x1bMigrateSynchronizerResponse\"\xa2\x05\n\x13\x45xportAcsOldRequest\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\x12\x34\n\x16\x66ilter_synchronizer_id\x18\x02 \x01(\tR\x14\x66ilterSynchronizerId\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\xa7\x01\n\x1d\x63ontract_synchronizer_renames\x18\x04 \x03(\x0b\x32\x63.com.digitalasset.canton.admin.participant.v30.ExportAcsOldRequest.ContractSynchronizerRenamesEntryR\x1b\x63ontractSynchronizerRenames\x12\x14\n\x05\x66orce\x18\x05 \x01(\x08R\x05\x66orce\x12/\n\x13parties_offboarding\x18\x06 \x01(\x08R\x12partiesOffboarding\x1ah\n\x12TargetSynchronizer\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12)\n\x10protocol_version\x18\x02 \x01(\x05R\x0fprotocolVersion\x1a\xa5\x01\n ContractSynchronizerRenamesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12k\n\x05value\x18\x02 \x01(\x0b\x32U.com.digitalasset.canton.admin.participant.v30.ExportAcsOldRequest.TargetSynchronizerR\x05value:\x02\x38\x01\",\n\x14\x45xportAcsOldResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\xba\x01\n\x13ImportAcsOldRequest\x12!\n\x0c\x61\x63s_snapshot\x18\x01 \x01(\x0cR\x0b\x61\x63sSnapshot\x12,\n\x12workflow_id_prefix\x18\x02 \x01(\tR\x10workflowIdPrefix\x12R\n&allow_contract_id_suffix_recomputation\x18\x03 \x01(\x08R\"allowContractIdSuffixRecomputation\"\xe9\x01\n\x14ImportAcsOldResponse\x12\x8a\x01\n\x13\x63ontract_id_mapping\x18\x01 \x03(\x0b\x32Z.com.digitalasset.canton.admin.participant.v30.ImportAcsOldResponse.ContractIdMappingEntryR\x11\x63ontractIdMapping\x1a\x44\n\x16\x43ontractIdMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xfb\x01\n\x10ImportAcsRequest\x12!\n\x0c\x61\x63s_snapshot\x18\x01 \x01(\x0cR\x0b\x61\x63sSnapshot\x12,\n\x12workflow_id_prefix\x18\x02 \x01(\tR\x10workflowIdPrefix\x12\x95\x01\n%contract_id_suffix_recomputation_mode\x18\x03 \x01(\x0e\x32\x43.com.digitalasset.canton.admin.participant.v30.ContractIdImportModeR!contractIdSuffixRecomputationMode\"\xe7\x01\n\x11ImportAcsResponse\x12\x8a\x01\n\x14\x63ontract_id_mappings\x18\x01 \x03(\x0b\x32X.com.digitalasset.canton.admin.participant.v30.ImportAcsResponse.ContractIdMappingsEntryR\x12\x63ontractIdMappings\x1a\x45\n\x17\x43ontractIdMappingsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"T\n#PurgeDeactivatedSynchronizerRequest\x12-\n\x12synchronizer_alias\x18\x01 \x01(\tR\x11synchronizerAlias\"&\n$PurgeDeactivatedSynchronizerResponse\"\x9e\x01\n\x13IgnoreEventsRequest\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12%\n\x0e\x66rom_inclusive\x18\x02 \x01(\x03R\rfromInclusive\x12!\n\x0cto_inclusive\x18\x03 \x01(\x03R\x0btoInclusive\x12\x14\n\x05\x66orce\x18\x04 \x01(\x08R\x05\x66orce\"\x16\n\x14IgnoreEventsResponse\"\xa0\x01\n\x15UnignoreEventsRequest\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12%\n\x0e\x66rom_inclusive\x18\x02 \x01(\x03R\rfromInclusive\x12!\n\x0cto_inclusive\x18\x03 \x01(\x03R\x0btoInclusive\x12\x14\n\x05\x66orce\x18\x04 \x01(\x08R\x05\x66orce\"\x18\n\x16UnignoreEventsResponse\"\xaa\x01\n\x1bRollbackUnassignmentRequest\x12\x1f\n\x0bunassign_id\x18\x01 \x01(\tR\nunassignId\x12\x34\n\x16source_synchronizer_id\x18\x02 \x01(\tR\x14sourceSynchronizerId\x12\x34\n\x16target_synchronizer_id\x18\x03 \x01(\tR\x14targetSynchronizerId\"\x1e\n\x1cRollbackUnassignmentResponse*\xb6\x01\n\x14\x43ontractIdImportMode\x12\'\n#CONTRACT_ID_IMPORT_MODE_UNSPECIFIED\x10\x00\x12\"\n\x1e\x43ONTRACT_ID_IMPORT_MODE_ACCEPT\x10\x01\x12&\n\"CONTRACT_ID_IMPORT_MODE_VALIDATION\x10\x02\x12)\n%CONTRACT_ID_IMPORT_MODE_RECOMPUTATION\x10\x03\x32\x93\r\n\x18ParticipantRepairService\x12\x99\x01\n\x0c\x45xportAcsOld\x12\x42.com.digitalasset.canton.admin.participant.v30.ExportAcsOldRequest\x1a\x43.com.digitalasset.canton.admin.participant.v30.ExportAcsOldResponse0\x01\x12\x99\x01\n\x0cImportAcsOld\x12\x42.com.digitalasset.canton.admin.participant.v30.ImportAcsOldRequest\x1a\x43.com.digitalasset.canton.admin.participant.v30.ImportAcsOldResponse(\x01\x12\x90\x01\n\tImportAcs\x12?.com.digitalasset.canton.admin.participant.v30.ImportAcsRequest\x1a@.com.digitalasset.canton.admin.participant.v30.ImportAcsResponse(\x01\x12\x9d\x01\n\x0ePurgeContracts\x12\x44.com.digitalasset.canton.admin.participant.v30.PurgeContractsRequest\x1a\x45.com.digitalasset.canton.admin.participant.v30.PurgeContractsResponse\x12\xac\x01\n\x13MigrateSynchronizer\x12I.com.digitalasset.canton.admin.participant.v30.MigrateSynchronizerRequest\x1aJ.com.digitalasset.canton.admin.participant.v30.MigrateSynchronizerResponse\x12\xa6\x01\n\x11\x43hangeAssignation\x12G.com.digitalasset.canton.admin.participant.v30.ChangeAssignationRequest\x1aH.com.digitalasset.canton.admin.participant.v30.ChangeAssignationResponse\x12\xc7\x01\n\x1cPurgeDeactivatedSynchronizer\x12R.com.digitalasset.canton.admin.participant.v30.PurgeDeactivatedSynchronizerRequest\x1aS.com.digitalasset.canton.admin.participant.v30.PurgeDeactivatedSynchronizerResponse\x12\x97\x01\n\x0cIgnoreEvents\x12\x42.com.digitalasset.canton.admin.participant.v30.IgnoreEventsRequest\x1a\x43.com.digitalasset.canton.admin.participant.v30.IgnoreEventsResponse\x12\x9d\x01\n\x0eUnignoreEvents\x12\x44.com.digitalasset.canton.admin.participant.v30.UnignoreEventsRequest\x1a\x45.com.digitalasset.canton.admin.participant.v30.UnignoreEventsResponse\x12\xaf\x01\n\x14RollbackUnassignment\x12J.com.digitalasset.canton.admin.participant.v30.RollbackUnassignmentRequest\x1aK.com.digitalasset.canton.admin.participant.v30.RollbackUnassignmentResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.participant_repair_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_EXPORTACSOLDREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._loaded_options = None
  _globals['_EXPORTACSOLDREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._serialized_options = b'8\001'
  _globals['_IMPORTACSOLDRESPONSE_CONTRACTIDMAPPINGENTRY']._loaded_options = None
  _globals['_IMPORTACSOLDRESPONSE_CONTRACTIDMAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGSENTRY']._loaded_options = None
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGSENTRY']._serialized_options = b'8\001'
  _globals['_CONTRACTIDIMPORTMODE']._serialized_start=3537
  _globals['_CONTRACTIDIMPORTMODE']._serialized_end=3719
  _globals['_PURGECONTRACTSREQUEST']._serialized_start=242
  _globals['_PURGECONTRACTSREQUEST']._serialized_end=399
  _globals['_PURGECONTRACTSRESPONSE']._serialized_start=401
  _globals['_PURGECONTRACTSRESPONSE']._serialized_end=425
  _globals['_CHANGEASSIGNATIONREQUEST']._serialized_start=428
  _globals['_CHANGEASSIGNATIONREQUEST']._serialized_end=859
  _globals['_CHANGEASSIGNATIONREQUEST_CONTRACT']._serialized_start=726
  _globals['_CHANGEASSIGNATIONREQUEST_CONTRACT']._serialized_end=859
  _globals['_CHANGEASSIGNATIONRESPONSE']._serialized_start=861
  _globals['_CHANGEASSIGNATIONRESPONSE']._serialized_end=888
  _globals['_MIGRATESYNCHRONIZERREQUEST']._serialized_start=891
  _globals['_MIGRATESYNCHRONIZERREQUEST']._serialized_end=1162
  _globals['_MIGRATESYNCHRONIZERRESPONSE']._serialized_start=1164
  _globals['_MIGRATESYNCHRONIZERRESPONSE']._serialized_end=1193
  _globals['_EXPORTACSOLDREQUEST']._serialized_start=1196
  _globals['_EXPORTACSOLDREQUEST']._serialized_end=1870
  _globals['_EXPORTACSOLDREQUEST_TARGETSYNCHRONIZER']._serialized_start=1598
  _globals['_EXPORTACSOLDREQUEST_TARGETSYNCHRONIZER']._serialized_end=1702
  _globals['_EXPORTACSOLDREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._serialized_start=1705
  _globals['_EXPORTACSOLDREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._serialized_end=1870
  _globals['_EXPORTACSOLDRESPONSE']._serialized_start=1872
  _globals['_EXPORTACSOLDRESPONSE']._serialized_end=1916
  _globals['_IMPORTACSOLDREQUEST']._serialized_start=1919
  _globals['_IMPORTACSOLDREQUEST']._serialized_end=2105
  _globals['_IMPORTACSOLDRESPONSE']._serialized_start=2108
  _globals['_IMPORTACSOLDRESPONSE']._serialized_end=2341
  _globals['_IMPORTACSOLDRESPONSE_CONTRACTIDMAPPINGENTRY']._serialized_start=2273
  _globals['_IMPORTACSOLDRESPONSE_CONTRACTIDMAPPINGENTRY']._serialized_end=2341
  _globals['_IMPORTACSREQUEST']._serialized_start=2344
  _globals['_IMPORTACSREQUEST']._serialized_end=2595
  _globals['_IMPORTACSRESPONSE']._serialized_start=2598
  _globals['_IMPORTACSRESPONSE']._serialized_end=2829
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGSENTRY']._serialized_start=2760
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGSENTRY']._serialized_end=2829
  _globals['_PURGEDEACTIVATEDSYNCHRONIZERREQUEST']._serialized_start=2831
  _globals['_PURGEDEACTIVATEDSYNCHRONIZERREQUEST']._serialized_end=2915
  _globals['_PURGEDEACTIVATEDSYNCHRONIZERRESPONSE']._serialized_start=2917
  _globals['_PURGEDEACTIVATEDSYNCHRONIZERRESPONSE']._serialized_end=2955
  _globals['_IGNOREEVENTSREQUEST']._serialized_start=2958
  _globals['_IGNOREEVENTSREQUEST']._serialized_end=3116
  _globals['_IGNOREEVENTSRESPONSE']._serialized_start=3118
  _globals['_IGNOREEVENTSRESPONSE']._serialized_end=3140
  _globals['_UNIGNOREEVENTSREQUEST']._serialized_start=3143
  _globals['_UNIGNOREEVENTSREQUEST']._serialized_end=3303
  _globals['_UNIGNOREEVENTSRESPONSE']._serialized_start=3305
  _globals['_UNIGNOREEVENTSRESPONSE']._serialized_end=3329
  _globals['_ROLLBACKUNASSIGNMENTREQUEST']._serialized_start=3332
  _globals['_ROLLBACKUNASSIGNMENTREQUEST']._serialized_end=3502
  _globals['_ROLLBACKUNASSIGNMENTRESPONSE']._serialized_start=3504
  _globals['_ROLLBACKUNASSIGNMENTRESPONSE']._serialized_end=3534
  _globals['_PARTICIPANTREPAIRSERVICE']._serialized_start=3722
  _globals['_PARTICIPANTREPAIRSERVICE']._serialized_end=5405
# @@protoc_insertion_point(module_scope)
