# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/admin/party/v30/party_replication.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'com/digitalasset/canton/participant/admin/party/v30/party_replication.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....admin.participant.v30 import active_contract_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_active__contract__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKcom/digitalasset/canton/participant/admin/party/v30/party_replication.proto\x12\x33\x63om.digitalasset.canton.participant.admin.party.v30\x1a\x43\x63om/digitalasset/canton/admin/participant/v30/active_contract.proto\">\n\x1bPartyReplicationInstruction\x12\x1f\n\x0bmax_counter\x18\x01 \x01(\rR\nmaxCounter\"\x93\x05\n\x1dPartyReplicationSourceMessage\x12z\n\tacs_chunk\x18\x01 \x01(\x0b\x32[.com.digitalasset.canton.participant.admin.party.v30.PartyReplicationSourceMessage.AcsChunkH\x00R\x08\x61\x63sChunk\x12\xac\x01\n\x1bsource_participant_is_ready\x18\x02 \x01(\x0b\x32k.com.digitalasset.canton.participant.admin.party.v30.PartyReplicationSourceMessage.SourceParticipantIsReadyH\x00R\x18sourceParticipantIsReady\x12{\n\nend_of_acs\x18\x03 \x01(\x0b\x32[.com.digitalasset.canton.participant.admin.party.v30.PartyReplicationSourceMessage.EndOfACSH\x00R\x08\x65ndOfAcs\x1a\x8f\x01\n\x08\x41\x63sChunk\x12#\n\rchunk_counter\x18\x01 \x01(\rR\x0c\x63hunkCounter\x12^\n\tcontracts\x18\x02 \x03(\x0b\x32@.com.digitalasset.canton.admin.participant.v30.ActiveContractOldR\tcontracts\x1a\x1a\n\x18SourceParticipantIsReady\x1a\n\n\x08\x45ndOfACSB\x10\n\x0e\x64\x61ta_or_statusBdZbgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/party/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.admin.party.v30.party_replication_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Zbgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/party/v30'
  _globals['_PARTYREPLICATIONINSTRUCTION']._serialized_start=201
  _globals['_PARTYREPLICATIONINSTRUCTION']._serialized_end=263
  _globals['_PARTYREPLICATIONSOURCEMESSAGE']._serialized_start=266
  _globals['_PARTYREPLICATIONSOURCEMESSAGE']._serialized_end=925
  _globals['_PARTYREPLICATIONSOURCEMESSAGE_ACSCHUNK']._serialized_start=724
  _globals['_PARTYREPLICATIONSOURCEMESSAGE_ACSCHUNK']._serialized_end=867
  _globals['_PARTYREPLICATIONSOURCEMESSAGE_SOURCEPARTICIPANTISREADY']._serialized_start=869
  _globals['_PARTYREPLICATIONSOURCEMESSAGE_SOURCEPARTICIPANTISREADY']._serialized_end=895
  _globals['_PARTYREPLICATIONSOURCEMESSAGE_ENDOFACS']._serialized_start=897
  _globals['_PARTYREPLICATIONSOURCEMESSAGE_ENDOFACS']._serialized_end=907
# @@protoc_insertion_point(module_scope)
