# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/topology/admin/v30/common.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'com/digitalasset/canton/topology/admin/v30/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7com/digitalasset/canton/topology/admin/v30/common.proto\x12*com.digitalasset.canton.topology.admin.v30\x1a\x1fgoogle/protobuf/timestamp.proto\"\x95\x03\n\x14TopologyTransactions\x12[\n\x05items\x18\x01 \x03(\x0b\x32\x45.com.digitalasset.canton.topology.admin.v30.TopologyTransactions.ItemR\x05items\x1a\x9f\x02\n\x04Item\x12\x38\n\tsequenced\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tsequenced\x12\x39\n\nvalid_from\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tvalidFrom\x12;\n\x0bvalid_until\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nvalidUntil\x12 \n\x0btransaction\x18\x03 \x01(\x0cR\x0btransaction\x12.\n\x10rejection_reason\x18\x05 \x01(\tH\x00R\x0frejectionReason\x88\x01\x01\x42\x13\n\x11_rejection_reason\"\x8a\x03\n\x07StoreId\x12`\n\nauthorized\x18\x01 \x01(\x0b\x32>.com.digitalasset.canton.topology.admin.v30.StoreId.AuthorizedH\x00R\nauthorized\x12\x66\n\x0csynchronizer\x18\x02 \x01(\x0b\x32@.com.digitalasset.canton.topology.admin.v30.StoreId.SynchronizerH\x00R\x0csynchronizer\x12]\n\ttemporary\x18\x03 \x01(\x0b\x32=.com.digitalasset.canton.topology.admin.v30.StoreId.TemporaryH\x00R\ttemporary\x1a\x0c\n\nAuthorized\x1a\x1e\n\x0cSynchronizer\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x1a\x1f\n\tTemporary\x12\x12\n\x04name\x18\x01 \x01(\tR\x04nameB\x07\n\x05storeB[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.topology.admin.v30.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30'
  _globals['_TOPOLOGYTRANSACTIONS']._serialized_start=137
  _globals['_TOPOLOGYTRANSACTIONS']._serialized_end=542
  _globals['_TOPOLOGYTRANSACTIONS_ITEM']._serialized_start=255
  _globals['_TOPOLOGYTRANSACTIONS_ITEM']._serialized_end=542
  _globals['_STOREID']._serialized_start=545
  _globals['_STOREID']._serialized_end=939
  _globals['_STOREID_AUTHORIZED']._serialized_start=853
  _globals['_STOREID_AUTHORIZED']._serialized_end=865
  _globals['_STOREID_SYNCHRONIZER']._serialized_start=867
  _globals['_STOREID_SYNCHRONIZER']._serialized_end=897
  _globals['_STOREID_TEMPORARY']._serialized_start=899
  _globals['_STOREID_TEMPORARY']._serialized_end=930
# @@protoc_insertion_point(module_scope)
