# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/party_management_service.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'com/digitalasset/canton/admin/participant/v30/party_management_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLcom/digitalasset/canton/admin/participant/v30/party_management_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa8\x01\n\x14\x41\x64\x64PartyAsyncRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12\x34\n\x16source_participant_uid\x18\x03 \x01(\tR\x14sourceParticipantUid\x12\x16\n\x06serial\x18\x04 \x01(\rR\x06serial\"H\n\x15\x41\x64\x64PartyAsyncResponse\x12/\n\x14\x61\x64\x64_party_request_id\x18\x01 \x01(\tR\x11\x61\x64\x64PartyRequestId\"K\n\x18GetAddPartyStatusRequest\x12/\n\x14\x61\x64\x64_party_request_id\x18\x01 \x01(\tR\x11\x61\x64\x64PartyRequestId\"\x81\x13\n\x19GetAddPartyStatusResponse\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12\x34\n\x16source_participant_uid\x18\x03 \x01(\tR\x14sourceParticipantUid\x12\x34\n\x16target_participant_uid\x18\x04 \x01(\tR\x14targetParticipantUid\x12g\n\x06status\x18\x05 \x01(\x0b\x32O.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.StatusR\x06status\x1a\xca\x10\n\x06Status\x12\x92\x01\n\x12proposal_processed\x18\x01 \x01(\x0b\x32\x61.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.ProposalProcessedH\x00R\x11proposalProcessed\x12\x92\x01\n\x12\x61greement_accepted\x18\x02 \x01(\x0b\x32\x61.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.AgreementAcceptedH\x00R\x11\x61greementAccepted\x12\x95\x01\n\x13topology_authorized\x18\x03 \x01(\x0b\x32\x62.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.TopologyAuthorizedH\x00R\x12topologyAuthorized\x12\x9e\x01\n\x16\x63onnection_established\x18\x04 \x01(\x0b\x32\x65.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.ConnectionEstablishedH\x00R\x15\x63onnectionEstablished\x12\x89\x01\n\x0freplicating_acs\x18\x05 \x01(\x0b\x32^.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.ReplicatingAcsH\x00R\x0ereplicatingAcs\x12y\n\tcompleted\x18\x06 \x01(\x0b\x32Y.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.CompletedH\x00R\tcompleted\x12m\n\x05\x65rror\x18\x07 \x01(\x0b\x32U.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.ErrorH\x00R\x05\x65rror\x1aU\n\x11ProposalProcessed\x12,\n\x0ftopology_serial\x18\x01 \x01(\rH\x00R\x0etopologySerial\x88\x01\x01\x42\x12\n\x10_topology_serial\x1az\n\x11\x41greementAccepted\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12,\n\x0ftopology_serial\x18\x02 \x01(\rH\x00R\x0etopologySerial\x88\x01\x01\x42\x12\n\x10_topology_serial\x1a\x9c\x01\n\x12TopologyAuthorized\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12\'\n\x0ftopology_serial\x18\x02 \x01(\rR\x0etopologySerial\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x1a\x9f\x01\n\x15\x43onnectionEstablished\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12\'\n\x0ftopology_serial\x18\x02 \x01(\rR\x0etopologySerial\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x1a\xcb\x01\n\x0eReplicatingAcs\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12\'\n\x0ftopology_serial\x18\x02 \x01(\rR\x0etopologySerial\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x31\n\x14\x63ontracts_replicated\x18\x04 \x01(\rR\x13\x63ontractsReplicated\x1a\xc6\x01\n\tCompleted\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12\'\n\x0ftopology_serial\x18\x02 \x01(\rR\x0etopologySerial\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x31\n\x14\x63ontracts_replicated\x18\x04 \x01(\rR\x13\x63ontractsReplicated\x1a\xb1\x01\n\x05\x45rror\x12#\n\rerror_message\x18\x01 \x01(\tR\x0c\x65rrorMessage\x12\x82\x01\n\x15status_prior_to_error\x18\x02 \x01(\x0b\x32O.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.StatusR\x12statusPriorToErrorB\x08\n\x06status\"S\n\x1b\x45xportAcsTargetSynchronizer\x12\x34\n\x16target_synchronizer_id\x18\x01 \x01(\tR\x14targetSynchronizerId\"\xc1\x03\n\x10\x45xportAcsRequest\x12\x1b\n\tparty_ids\x18\x01 \x03(\tR\x08partyIds\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12#\n\rledger_offset\x18\x03 \x01(\x03R\x0cledgerOffset\x12\xa4\x01\n\x1d\x63ontract_synchronizer_renames\x18\x04 \x03(\x0b\x32`.com.digitalasset.canton.admin.participant.v30.ExportAcsRequest.ContractSynchronizerRenamesEntryR\x1b\x63ontractSynchronizerRenames\x1a\x9a\x01\n ContractSynchronizerRenamesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12`\n\x05value\x18\x02 \x01(\x0b\x32J.com.digitalasset.canton.admin.participant.v30.ExportAcsTargetSynchronizerR\x05value:\x02\x38\x01\")\n\x11\x45xportAcsResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\xce\x01\n\x1b\x45xportAcsAtTimestampRequest\x12\x1b\n\tparty_ids\x18\x01 \x03(\tR\x08partyIds\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12i\n#topology_transaction_effective_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR topologyTransactionEffectiveTime\"4\n\x1c\x45xportAcsAtTimestampResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk2\xa5\x05\n\x16PartyManagementService\x12\x9a\x01\n\rAddPartyAsync\x12\x43.com.digitalasset.canton.admin.participant.v30.AddPartyAsyncRequest\x1a\x44.com.digitalasset.canton.admin.participant.v30.AddPartyAsyncResponse\x12\xa6\x01\n\x11GetAddPartyStatus\x12G.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusRequest\x1aH.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse\x12\x90\x01\n\tExportAcs\x12?.com.digitalasset.canton.admin.participant.v30.ExportAcsRequest\x1a@.com.digitalasset.canton.admin.participant.v30.ExportAcsResponse0\x01\x12\xb1\x01\n\x14\x45xportAcsAtTimestamp\x12J.com.digitalasset.canton.admin.participant.v30.ExportAcsAtTimestampRequest\x1aK.com.digitalasset.canton.admin.participant.v30.ExportAcsAtTimestampResponse0\x01\x42^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.party_management_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_EXPORTACSREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._loaded_options = None
  _globals['_EXPORTACSREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._serialized_options = b'8\001'
  _globals['_ADDPARTYASYNCREQUEST']._serialized_start=161
  _globals['_ADDPARTYASYNCREQUEST']._serialized_end=329
  _globals['_ADDPARTYASYNCRESPONSE']._serialized_start=331
  _globals['_ADDPARTYASYNCRESPONSE']._serialized_end=403
  _globals['_GETADDPARTYSTATUSREQUEST']._serialized_start=405
  _globals['_GETADDPARTYSTATUSREQUEST']._serialized_end=480
  _globals['_GETADDPARTYSTATUSRESPONSE']._serialized_start=483
  _globals['_GETADDPARTYSTATUSRESPONSE']._serialized_end=2916
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS']._serialized_start=794
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS']._serialized_end=2916
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_PROPOSALPROCESSED']._serialized_start=1789
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_PROPOSALPROCESSED']._serialized_end=1874
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_AGREEMENTACCEPTED']._serialized_start=1876
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_AGREEMENTACCEPTED']._serialized_end=1998
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_TOPOLOGYAUTHORIZED']._serialized_start=2001
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_TOPOLOGYAUTHORIZED']._serialized_end=2157
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_CONNECTIONESTABLISHED']._serialized_start=2160
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_CONNECTIONESTABLISHED']._serialized_end=2319
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_REPLICATINGACS']._serialized_start=2322
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_REPLICATINGACS']._serialized_end=2525
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_COMPLETED']._serialized_start=2528
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_COMPLETED']._serialized_end=2726
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_ERROR']._serialized_start=2729
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_ERROR']._serialized_end=2906
  _globals['_EXPORTACSTARGETSYNCHRONIZER']._serialized_start=2918
  _globals['_EXPORTACSTARGETSYNCHRONIZER']._serialized_end=3001
  _globals['_EXPORTACSREQUEST']._serialized_start=3004
  _globals['_EXPORTACSREQUEST']._serialized_end=3453
  _globals['_EXPORTACSREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._serialized_start=3299
  _globals['_EXPORTACSREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._serialized_end=3453
  _globals['_EXPORTACSRESPONSE']._serialized_start=3455
  _globals['_EXPORTACSRESPONSE']._serialized_end=3496
  _globals['_EXPORTACSATTIMESTAMPREQUEST']._serialized_start=3499
  _globals['_EXPORTACSATTIMESTAMPREQUEST']._serialized_end=3705
  _globals['_EXPORTACSATTIMESTAMPRESPONSE']._serialized_start=3707
  _globals['_EXPORTACSATTIMESTAMPRESPONSE']._serialized_end=3759
  _globals['_PARTYMANAGEMENTSERVICE']._serialized_start=3762
  _globals['_PARTYMANAGEMENTSERVICE']._serialized_end=4439
# @@protoc_insertion_point(module_scope)
